@@ -1,5 +1,5 @@
 #![allow(dead_code)]
 
 pub const PUSHOVER_API_ENDPOINT: &str = "https://api.pushover.net/1/messages.json";
-pub const PUSHOVER_API_REQUEST_METHOD: &str = "POST";
 pub const PUSHOVER_API_DOCUMENTATION_URL: &str = "https://pushover.net/api";
+pub const PUSHOVER_API_ATTACHMENT_MAX_SIZE_BYTES: u64 = 2621440;
