@@ -1,10 +1,14 @@
 // Submodule name masking
 mod message;
 mod message_builder;
+mod attachment_message;
+mod attachment_message_builder;
 mod pushover_sounds;
 mod pushover_response;
 
 pub use message::*;
+pub use attachment_message::*;
 pub use message_builder::*;
 pub use pushover_sounds::*;
 pub use pushover_response::*;
+pub use attachment_message_builder::*;
